@@ -1,3 +1,5 @@
+import copy
+
 from enum import Enum
 
 
@@ -5,11 +7,13 @@ class Shard(Enum):
     PC_AS = 'pc-as'  # Asia
     PC_EU = 'pc-eu'  # Europe
     PC_KAKAO = 'pc-kakao'  # Kakaogames server (Korea only)
-    PC_KRJP = 'pc-krjp'  # Korea/Japan
+    PC_KRJP = 'pc-krjp'  # Korea
     PC_NA = 'pc-na'  # North America
     PC_OC = 'pc-oc'  # Oceania
     PC_SA = 'pc-sa'  # South and Central America
     PC_SEA = 'pc-sea'  # South East Asia
+    PC_JP = 'pc-jp'  # Japan
+    PC_RU = 'pc-ru'  # Russia
     XBOX_AS = 'xbox-as'  # Asia
     XBOX_EU = 'xbox-eu'  # Europe
     XBOX_NA = 'xbox-na'  # North America
@@ -26,7 +30,7 @@ class Filter(Enum):
 class Domain:
 
     def __init__(self, data, meta=None):
-        self._raw_data = data
+        self._raw_data = copy.deepcopy(data)
         self._meta = meta or Meta(self._raw_data)
         self._data = self._raw_data.pop('data')
         self.from_dict()
@@ -78,6 +82,15 @@ class Meta:
             filter(lambda x: x['id'] == data['id'], self._included), data)
 
 
+class Sample(Domain):
+
+    def from_dict(self):
+        super().from_dict()
+        self.created_at = self.attributes.get('createdAt')
+        self.shard_id = self.attributes.get('shardId')
+        self.title_id = self.attributes.get('titleId')
+
+
 class Match(Domain):
 
     def from_dict(self):
@@ -91,6 +104,7 @@ class Match(Domain):
         self.shard_id = self.attributes.get('shardId')
         self.tags = self.attributes.get('tags')
         self.map = self.attributes.get('mapName')
+        self.is_custom = self.attributes.get('isCustomMatch')
 
 
 class Roster(Domain):
@@ -120,11 +134,10 @@ class Participant(Domain):
         self.headshot_kills = self.stats.get('headshotKills')
         self.heals = self.stats.get('heals')
         self.kill_place = self.stats.get('killPlace')
+        self.kill_points = self.stats.get('killPoints')
         self.kill_points_delta = self.stats.get('killPointsDelta')
         self.kill_streaks = self.stats.get('killStreaks')
         self.kills = self.stats.get('kills')
-        self.last_kill_points = self.stats.get('lastKillPoints')
-        self.last_win_points = self.stats.get('lastWinPoints')
         self.longest_kill = self.stats.get('longestKill')
         self.most_damage = self.stats.get('mostDamage')
         self.name = self.stats.get('name')
@@ -138,6 +151,7 @@ class Participant(Domain):
         self.walk_distance = self.stats.get('walkDistance')
         self.weapons_acquired = self.stats.get('weaponsAcquired')
         self.win_place = self.stats.get('winPlace')
+        self.win_points = self.stats.get('winPoints')
         self.win_points_delta = self.stats.get('winPointsDelta')
 
 
@@ -161,4 +175,4 @@ class Player(Domain):
         self.shard_id = self.attributes.get('shardId')
         self.stats = self.attributes.get('stats')
         self.title_id = self.attributes.get('titleId')
-        self.updated_at = self.attributes.get('updated_at')
+        self.updated_at = self.attributes.get('updatedAt')
